class HmiKeyConstants:
    APU_IP_ADDRESS = "apu_ip_address"
    HMI_HOSTNAME = "hmi_hostname"
    HMI_HOMEPAGE = "hmi_homepage"
    HMI_IP_ADDRESS_TYPE = "hmi_ip_address_type"
    HMI_IP_ADDRESS = "hmi_ip_address"
    HMI_NETMASK = "hmi_netmask"
    HMI_DEFAULT_GATEWAY = "hmi_default_gateway"
    HMI_DNS = "hmi_dns"
